@@ -32,7 +32,7 @@ setConstructorS3("AffineSnpPlm", function(..., mergeStrands=FALSE) {
 
 setMethodS3("getAsteriskTags", "AffineSnpPlm", function(this, collapse=NULL, ...) {
   # Returns 'AFF[,<flavor>]'
-  tags <- NextMethod("getAsteriskTags", this, collapse=collapse, ...);
+  tags <- NextMethod("getAsteriskTags", collapse=collapse);
 
   # Add class specific parameter tags
   if (!this$mergeStrands)
