@@ -88,7 +88,7 @@ setMethodS3("as.character", "DChipDcpSet", function(x, ...) {
   tags <- paste(tags, collapse=",");
   s <- c(s, sprintf("Tags: %s", tags));
   s <- c(s, sprintf("Path: %s", getPath(this)));
-  n <- nbrOfArrays(this);
+  n <- length(this);
   s <- c(s, sprintf("Number of arrays: %d", n));
   names <- getNames(this);
   s <- c(s, sprintf("Names: %s [%d]", hpaste(names), n));
@@ -96,7 +96,7 @@ setMethodS3("as.character", "DChipDcpSet", function(x, ...) {
   s <- c(s, sprintf("RAM: %.2fMB", objectSize(this)/1024^2));
   class(s) <- "GenericSummary";
   s;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
@@ -109,20 +109,8 @@ setMethodS3("findByName", "DChipDcpSet", function(static, ..., paths=c("rawData(
     paths <- eval(formals(findByName.DChipDcpSet)[["paths"]]);
   }
 
-
-  # Unfortunately method dispatching does not work here.
-  path <- findByName.AffymetrixCelSet(static, ..., paths=paths);
-  
-  path;
-}, static=TRUE)
-
-
-setMethodS3("fromName", "DChipDcpSet", function(static, ...) {
-  className <- class(static)[1];
-  msg <- sprintf("%s$fromName() is defunct. Use %s$byName() instead.", 
-                                                className, className);
-  throw(msg);
-}, static=TRUE, deprecated=TRUE)
+  NextMethod("findByName", paths=paths);
+}, static=TRUE, protected=TRUE)
 
 
 setMethodS3("byName", "DChipDcpSet", function(static, name, tags=NULL, chipType, paths=NULL, ...) {
@@ -157,12 +145,12 @@ setMethodS3("byPath", "DChipDcpSet", function(static, path="rawData/", pattern="
   
   verbose && enter(verbose, "Defining ", class(static)[1], " from files");
 
-  this <- byPath.AffymetrixFileSet(static, path=path, pattern=pattern, ..., fileClass=fileClass, verbose=less(verbose));
+  this <- NextMethod("byPath", path=path, pattern=pattern, fileClass=fileClass, verbose=less(verbose));
 
-  verbose && cat(verbose, "Retrieved files: ", nbrOfFiles(this));
+  verbose && cat(verbose, "Retrieved files: ", length(this));
 
 
-  if (nbrOfFiles(this) > 0) {
+  if (length(this) > 0) {
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
     # Scan all CHP files for possible chip types
     # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
@@ -176,7 +164,7 @@ setMethodS3("byPath", "DChipDcpSet", function(static, path="rawData/", pattern="
   verbose && exit(verbose);
 
   this;
-})
+}, protected=TRUE)
 
 
 
@@ -188,7 +176,7 @@ setMethodS3("byPath", "DChipDcpSet", function(static, path="rawData/", pattern="
 #
 # \description{
 #   @get "title".
-#   This is just a wrapper for \code{nbrOfFiles()}.
+#   This is just a wrapper for \code{length()}.
 # }
 #
 # @synopsis
@@ -208,8 +196,8 @@ setMethodS3("byPath", "DChipDcpSet", function(static, path="rawData/", pattern="
 # }
 #*/###########################################################################
 setMethodS3("nbrOfArrays", "DChipDcpSet", function(this, ...) {
-  nbrOfFiles(this, ...);
-})
+  length(this, ...);
+}, protected=TRUE)
 
 
 
@@ -272,9 +260,9 @@ setMethodS3("extractTheta", "DChipDcpSet", function(this, units=NULL, ..., drop=
   # Extract the thetas
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - 
   data <- NULL;
-  nbrOfArrays <- nbrOfArrays(this);
+  nbrOfArrays <- length(this);
   gcCount <- 0;
-  for (kk in seq(length=nbrOfArrays)) {
+  for (kk in seq_len(nbrOfArrays)) {
     df <- getFile(this, kk);
     verbose && enter(verbose, sprintf("Array #%d ('%s') of %d", kk, getName(df), nbrOfArrays));
 
