@@ -127,7 +127,7 @@ original CDF. NOTE: This will take several minutes or more!");
 
 
 setMethodS3("readUnits", "FirmaFile", function(this, units=NULL, cdf=NULL,
-..., force=FALSE, cache=TRUE, verbose=FALSE) {
+..., force=FALSE, cache=FALSE, verbose=FALSE) {
   # Argument 'verbose':
   verbose <- Arguments$getVerbose(verbose);
 
@@ -135,6 +135,9 @@ setMethodS3("readUnits", "FirmaFile", function(this, units=NULL, cdf=NULL,
   key <- list(method="readUnits", class=class(this)[1],
               pathname=getPathname(this),
               cdf=cdf, units=units, ...);
+  if (getOption(aromaSettings, "devel/useCacheKeyInterface", FALSE)) {
+    key <- getCacheKey(this, method="readUnits", pathname=getPathname(this), cdf=cdf, units=units, ...);
+  }
   id <- digest2(key);
   res <- this$.readUnitsCache[[id]];
   if (!force && !is.null(res)) {
@@ -163,9 +166,41 @@ setMethodS3("readUnits", "FirmaFile", function(this, units=NULL, cdf=NULL,
   res;
 })
 
+
+###########################################################################/**
+# @RdocMethod getCellIndices
+#
+# @title "Retrieves tree list of cell indices for a set of units"
+#
+# \description{
+#   @get "title" from the associated CDF.
+# }
+#
+# @synopsis
+#
+# \arguments{
+#  \item{...}{Additional arguments passed to \code{getCellIndices()}
+#             of @see "AffymetrixCdfFile".}
+#  \item{.cache}{Ignored.}
+# }
+#
+# \value{
+#   Returns a @list structure, where each element corresponds to a unit.
+#   If argument \code{unlist=TRUE} is passed, an @integer @vector is returned.
+# }
+#
+# @author
+#
+# \seealso{
+#   @seeclass
+# }
+#
+# @keyword internal
+#*/###########################################################################
 setMethodS3("getCellIndices", "FirmaFile", function(this, ..., .cache=TRUE) {
-  getCellIndices(getCdf(this), ...);
-})
+  cdf <- getCdf(this);
+  getCellIndices(cdf, ...);
+}, protected=TRUE)
 
 
 
@@ -303,7 +338,7 @@ setMethodS3("getUnitGroupCellMap", "FirmaFile", function(this, units=NULL, ...,
 
   unitNames <- names(cells);
 # BUG!  Fix this in ChipEffectFile.R
-#  unitSizes <- unlist(base::lapply(cells, length), use.names=FALSE);
+#  unitSizes <- unlist(base::lapply(cells, FUN=length), use.names=FALSE);
   unitSizes <- unlist(base::lapply(cells, FUN=function(unit){
     length(.subset2(unit,"groups"));
   }), use.names=FALSE);  
