@@ -78,7 +78,7 @@ setMethodS3("getCellIndices", "FirmaSet", function(this, ...) {
   # Use the first file to get the CDF structure.
   # Note: Ideally we want to define a special CDF class doing this
   # instead of letting the data file do this. /HB 2006-12-18
-  ff <- getFile(this, 1);
+  ff <- getOneFile(this);
   getCellIndices(ff, ...);
 })
 
@@ -110,7 +110,7 @@ setMethodS3("readUnits", "FirmaSet", function(this, units=NULL, cdf=NULL, ..., v
 
   # Get first file and use that to decode the read structure
   # This takes some time for a large number of units /HB 2006-10-04
-  ff <- getFile(this, 1);
+  ff <- getOneFile(this);
   res <- decode(ff, res, verbose=less(verbose));
 
   verbose && exit(verbose);
@@ -120,7 +120,7 @@ setMethodS3("readUnits", "FirmaSet", function(this, units=NULL, cdf=NULL, ..., v
 
 setMethodS3("findUnitsTodo", "FirmaSet", function(this, ...) {
   # Look into the last file since that is updated last
-  ff <- getFile(this, 1);
+  ff <- getOneFile(this);
   findUnitsTodo(ff, ...);
 })
 
@@ -136,22 +136,23 @@ setMethodS3("updateUnits", "FirmaSet", function(this, units=NULL, cdf=NULL, data
 
   # Update each file one by one
   arrays <- seq_along(this);
-  nbrOfArrays <- length(this);
+  nbrOfArrays <- length(arrays);
   verbose && enter(verbose, "Updating ", nbrOfArrays, " FIRMA result files");
 
-  names <- getNames(this);
-
-  verbose && enter(verbose, "Making sure the files are updated in lexicographic order");
-  # Reorder such that the file with the "last" name is saved last
-  fullnames <- getFullNames(this);
-  o <- order(fullnames, decreasing=FALSE);
-  arrays <- arrays[o];
-  verbose && str(verbose, arrays);
-  verbose && cat(verbose, "Last array: ", fullnames[arrays[nbrOfArrays]]);
-  rm(fullnames, o);
-  verbose && exit(verbose);
+  if (nbrOfArrays > 1L) {
+    verbose && enter(verbose, "Making sure the files are updated in lexicographic order");
+    # Reorder such that the file with the "last" name is saved last
+    fullnames <- getFullNames(this);
+    o <- order(fullnames, decreasing=FALSE);
+    arrays <- arrays[o];
+    verbose && str(verbose, arrays);
+    verbose && cat(verbose, "Last array: ", fullnames[arrays[nbrOfArrays]]);
+    rm(fullnames, o);
+    verbose && exit(verbose);
+  }
 
   verbose <- less(verbose);
+  names <- getNames(this);
   for (ii in arrays) {
     verbose && enter(verbose, sprintf("Array #%d of %d: %s", 
                                        ii, nbrOfArrays, names[ii]));
