@@ -77,6 +77,8 @@ setConstructorS3("ReseqCrosstalkCalibration", function(dataSet=NULL, ..., target
   
 
   extend(ProbeLevelTransform(dataSet=dataSet, ...), "ReseqCrosstalkCalibration",
+    "cached.setsOfProbes" = NULL,
+    "cached.subsetToAvgExpanded" = NULL,
     .targetAvg = targetAvg,
     .subsetToAvg = subsetToAvg,
     .mergeGroups = mergeGroups,
@@ -89,19 +91,8 @@ setConstructorS3("ReseqCrosstalkCalibration", function(dataSet=NULL, ..., target
 })
 
 
-setMethodS3("clearCache", "ReseqCrosstalkCalibration", function(this, ...) {
-  # Clear all cached values.
-  for (ff in c(".setsOfProbes", ".subsetToAvgExpanded")) {
-    this[[ff]] <- NULL;
-  }
-
-  # Then for this object 
-  NextMethod("clearCache", object=this, ...);
-})
-
-
 setMethodS3("getAsteriskTags", "ReseqCrosstalkCalibration", function(this, collapse=NULL, ...) {
-  tags <- NextMethod("getAsteriskTags", this, collapse=collapse, ...);
+  tags <- NextMethod("getAsteriskTags", collapse=NULL);
 
   # 'mergeGroups' tag
   if (this$.mergeGroups) {
@@ -118,7 +109,7 @@ setMethodS3("getAsteriskTags", "ReseqCrosstalkCalibration", function(this, colla
   tags <- paste(tags, collapse=collapse);
 
   tags;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
@@ -193,7 +184,7 @@ setMethodS3("getSubsetToAvg", "ReseqCrosstalkCalibration", function(this, ..., v
 
 setMethodS3("getParameters", "ReseqCrosstalkCalibration", function(this, expand=TRUE, ...) {
   # Get parameters from super class
-  params <- NextMethod(generic="getParameters", object=this, expand=expand, ...);
+  params <- NextMethod("getParameters", expand=expand);
 
   params <- c(params, list(
     targetAvg = this$.targetAvg,
@@ -211,7 +202,7 @@ setMethodS3("getParameters", "ReseqCrosstalkCalibration", function(this, expand=
   }
 
   params;
-}, private=TRUE)
+}, protected=TRUE)
 
 
 
@@ -350,7 +341,7 @@ setMethodS3("fitOne", "ReseqCrosstalkCalibration", function(this, yAll, ..., ver
   fits <- vector("list", nbrOfUnits);
   names(fits) <- names(cellQuartets);
 
-  for (uu in seq(length=nbrOfUnits)) {
+  for (uu in seq_len(nbrOfUnits)) {
     keyUU <- names(cellQuartets)[uu];
     verbose && enter(verbose, sprintf("Unit #%d ('%s') of %d", 
                                            uu, keyUU, nbrOfUnits));
@@ -361,7 +352,7 @@ setMethodS3("fitOne", "ReseqCrosstalkCalibration", function(this, yAll, ..., ver
     fitsUU <- vector("list", nbrOfGroups);
     names(fitsUU) <- names(cellsUU);
 
-    for (gg in seq(length=nbrOfGroups)) {
+    for (gg in seq_len(nbrOfGroups)) {
       keyGG <- names(cellsUU)[gg];
       verbose && enter(verbose, sprintf("Group #%d ('%s') of %d", 
                                 gg, keyGG, nbrOfGroups));
@@ -423,7 +414,7 @@ setMethodS3("calibrateOne", "ReseqCrosstalkCalibration", function(this, yAll, fi
   rescaleFits <- vector("list", nbrOfUnits);
   names(rescaleFits) <- names(cellQuartets);
 
-  for (uu in seq(length=nbrOfUnits)) {
+  for (uu in seq_len(nbrOfUnits)) {
     keyUU <- names(cellQuartets)[uu];
     verbose && enter(verbose, sprintf("Unit #%d ('%s') of %d", 
                                            uu, keyUU, nbrOfUnits));
@@ -434,7 +425,7 @@ setMethodS3("calibrateOne", "ReseqCrosstalkCalibration", function(this, yAll, fi
 
     rescaleFitsUU <- vector("list", nbrOfGroups);
     names(rescaleFitsUU) <- names(fitsUU);
-    for (gg in seq(length=nbrOfGroups)) {
+    for (gg in seq_len(nbrOfGroups)) {
       keyGG <- names(cellsUU)[gg];
       verbose && enter(verbose, sprintf("Group #%d ('%s') of %d", 
                                            gg, keyGG, nbrOfGroups));
@@ -578,7 +569,7 @@ setMethodS3("process", "ReseqCrosstalkCalibration", function(this, ..., force=FA
   # Calibrate each array
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   cdf <- getCdf(ds);
-  nbrOfArrays <- nbrOfArrays(ds);
+  nbrOfArrays <- length(ds);
   verbose && enter(verbose, "Calibrating ", nbrOfArrays, " arrays");
   verbose && cat(verbose, "Path: ", outputPath);
   for (kk in seq_len(nbrOfArrays)) {
