@@ -29,7 +29,7 @@ setConstructorS3("SmoothSaModel", function(...) {
 
 
 setMethodS3("getAsteriskTags", "SmoothSaModel", function(this, collapse=NULL, ...) {
-  tags <- NextMethod("getAsteriskTags", this, collapse=NULL, ...);
+  tags <- NextMethod("getAsteriskTags", collapse=NULL);
 
   # Replace first tags
   tags[1] <- "SA";
@@ -47,7 +47,7 @@ setMethodS3("getAsteriskTags", "SmoothSaModel", function(this, collapse=NULL, ..
 
 setMethodS3("getFitUnitGroupFunction", "SmoothSaModel", function(this, ...) {
   smoothWSA;
-})
+}, protected=TRUE)
 
 
 ##############################################################################
