@@ -14,7 +14,7 @@ setMethodS3("doRMA", "AffymetrixCelSet", function(csR, arrays=NULL, ..., uniqueP
   # Argument 'arrays':
   if (!is.null(arrays)) {
     throw("Not supported. Argument 'arrays' should be NULL.");
-    arrays <- Arguments$getIndices(arrays, max=nbrOfArrays(csR));
+    arrays <- Arguments$getIndices(arrays, max=length(csR));
   }
 
   # Argument 'uniquePlm':
